==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d4/d2f/main__gui_8cpp.js <==
var main__gui_8cpp =
[
    [ "MainWindow", "d2/d48/structMainWindow.html", "d2/d48/structMainWindow" ],
    [ "GHK_QUIT", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9acc096f72b0e262a6a2513cf751027646", null ],
    [ "GHK_ABANDON", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9a0379d1b69d744e319ba16bd74e2dc661", null ],
    [ "GHK_CONSOLE", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9a024ca919a4b027a382017f6ce449cb87", null ],
    [ "GHK_BOUNDING_BOXES", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9a1a3a4b194151e91162a56c53a6a395f1", null ],
    [ "GHK_DIRTY_BLOCKS", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9a4eca2305f89cd954b9489f2b031059f1", null ],
    [ "GHK_CENTER", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9a424821fa775c80262ef8de47034c9c05", null ],
    [ "GHK_CENTER_ZOOM", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9a7681ca82aaff19541a9da0d55f00a122", null ],
    [ "GHK_RESET_OBJECT_TO_PLACE", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9aed41ea70731b1c7b7db391cee34c8d47", null ],
    [ "GHK_DELETE_WINDOWS", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9a7378127eef97d58a00b8c0d5de1ba1e7", null ],
    [ "GHK_DELETE_NONVITAL_WINDOWS", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9a0ecada4da8ef4dc61cff14d7b3ffa8d5", null ],
    [ "GHK_REFRESH_SCREEN", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9af42619bac7a57a86e2d5e6c512134004", null ],
    [ "GHK_CRASH", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9ad44d26d180900619fc6adadf488abae7", null ],
    [ "GHK_MONEY", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9af041cc5a7ae6dccc3c683f4ac12409d2", null ],
    [ "GHK_UPDATE_COORDS", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9ae28c731cd85da91e9070fcc8b28e7493", null ],
    [ "GHK_TOGGLE_TRANSPARENCY", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9a097867ca27cb5c0d7f21a97931f0c6a6", null ],
    [ "GHK_TOGGLE_INVISIBILITY", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9a01a9b5064f1d7efd504fc7e212aab2c8", null ],
    [ "GHK_TRANSPARENCY_TOOLBAR", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9a0ac650cc7fa5a9c3d3f513c133361f39", null ],
    [ "GHK_TRANSPARANCY", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9a092996092e1a020a316d069b263bcdd3", null ],
    [ "GHK_CHAT", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9a3386a7bc33316de51e6bdc0ea9eaf30d", null ],
    [ "GHK_CHAT_ALL", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9a4a5041690f97811ea7ff5bbe03451b42", null ],
    [ "GHK_CHAT_COMPANY", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9a6e9ddba220e30cf98bdab8a9a97014ef", null ],
    [ "GHK_CHAT_SERVER", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9a63c096645f6ecd5c1454c3e8bb56eff8", null ],
    [ "CcGiveMoney", "d4/d2f/main__gui_8cpp.html#ac50b4b2c0414a7627ad81803ee4ab7dd", null ],
    [ "CcPlaySound_EXPLOSION", "d4/d2f/main__gui_8cpp.html#ad46410ff3828be8c273231362427a202", null ],
    [ "DoZoomInOutWindow", "d4/d2f/main__gui_8cpp.html#adaa371fce2b46799616f97226d298105", null ],
    [ "GameSizeChanged", "d4/d2f/main__gui_8cpp.html#a4560d58565a10931cc872203e4507e0c", null ],
    [ "HandleOnEditText", "d4/d2f/main__gui_8cpp.html#a41a1cdfe4b8a1bd9be4a95bc0c1ada45", null ],
    [ "HandlePlacePushButton", "d4/d2f/main__gui_8cpp.html#adda47a64a5c71bef4d65e68a10fff5e9", null ],
    [ "IsQuitKey", "d4/d2f/main__gui_8cpp.html#a741c7924ee2ff2ded36abb79e10a7e36", null ],
    [ "SetupColoursAndInitialWindow", "d4/d2f/main__gui_8cpp.html#a55d3768f8fd70e0d8774f72cd07cb3c8", null ],
    [ "ShowNetworkGiveMoneyWindow", "d4/d2f/main__gui_8cpp.html#a299bd9e36376bab4ccfdfd05d176f5c2", null ],
    [ "ShowSelectGameWindow", "d4/d2f/main__gui_8cpp.html#a047378c986949dd9660b677fecd96847", null ],
    [ "ShowVitalWindows", "d4/d2f/main__gui_8cpp.html#a09240eb994f64bbd4dc0deef77da9263", null ],
    [ "ZoomInOrOutToCursorWindow", "d4/d2f/main__gui_8cpp.html#ad33aa4a7c820c1165c9265e2ef32041b", null ],
    [ "_ghk_abandon_keys", "d4/d2f/main__gui_8cpp.html#a5f25b4d5715ea614462edcf99b61e82c", null ],
    [ "_ghk_chat_all_keys", "d4/d2f/main__gui_8cpp.html#abb3ac94f4fc3059a9916921341ca9eb6", null ],
    [ "_ghk_chat_company_keys", "d4/d2f/main__gui_8cpp.html#a6cbbdfe69dcfcf312f62d921afcc51f9", null ],
    [ "_ghk_chat_keys", "d4/d2f/main__gui_8cpp.html#a3056e523e6df2326b5473a22f74e82ab", null ],
    [ "_ghk_chat_server_keys", "d4/d2f/main__gui_8cpp.html#a751aac66ab5762a454fc2de7ec11fa92", null ],
    [ "_ghk_quit_keys", "d4/d2f/main__gui_8cpp.html#a8be278d7bcfea2842e3ed66c2a43dff1", null ],
    [ "_main_window_desc", "d4/d2f/main__gui_8cpp.html#a7cc6ad9b1903c4ec22228375dd09d33a", null ],
    [ "_nested_main_window_widgets", "d4/d2f/main__gui_8cpp.html#a887d24014962a322a719b9232c6d2e9a", null ],
    [ "_rename_id", "d4/d2f/main__gui_8cpp.html#aaff64b8e7b5ac1ddadf92ecb6993b411", null ],
    [ "_rename_what", "d4/d2f/main__gui_8cpp.html#a2717c31e52411b586b9feb4189ef4150", null ],
    [ "global_hotkeys", "d4/d2f/main__gui_8cpp.html#a95061e381e0685497be87418a562ef98", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d4/d2f/main__gui_8cpp.js <==
var main__gui_8cpp =
[
    [ "MainWindow", "d2/d48/structMainWindow.html", "d2/d48/structMainWindow" ],
    [ "GHK_QUIT", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9acc096f72b0e262a6a2513cf751027646", null ],
    [ "GHK_ABANDON", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9a0379d1b69d744e319ba16bd74e2dc661", null ],
    [ "GHK_CONSOLE", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9a024ca919a4b027a382017f6ce449cb87", null ],
    [ "GHK_BOUNDING_BOXES", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9a1a3a4b194151e91162a56c53a6a395f1", null ],
    [ "GHK_DIRTY_BLOCKS", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9a4eca2305f89cd954b9489f2b031059f1", null ],
    [ "GHK_CENTER", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9a424821fa775c80262ef8de47034c9c05", null ],
    [ "GHK_CENTER_ZOOM", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9a7681ca82aaff19541a9da0d55f00a122", null ],
    [ "GHK_RESET_OBJECT_TO_PLACE", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9aed41ea70731b1c7b7db391cee34c8d47", null ],
    [ "GHK_DELETE_WINDOWS", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9a7378127eef97d58a00b8c0d5de1ba1e7", null ],
    [ "GHK_DELETE_NONVITAL_WINDOWS", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9a0ecada4da8ef4dc61cff14d7b3ffa8d5", null ],
    [ "GHK_DELETE_ALL_MESSAGES", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9ac9c145343dfd546760f44ba80fda1c8a", null ],
    [ "GHK_REFRESH_SCREEN", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9af42619bac7a57a86e2d5e6c512134004", null ],
    [ "GHK_CRASH", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9ad44d26d180900619fc6adadf488abae7", null ],
    [ "GHK_MONEY", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9af041cc5a7ae6dccc3c683f4ac12409d2", null ],
    [ "GHK_UPDATE_COORDS", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9ae28c731cd85da91e9070fcc8b28e7493", null ],
    [ "GHK_TOGGLE_TRANSPARENCY", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9a097867ca27cb5c0d7f21a97931f0c6a6", null ],
    [ "GHK_TOGGLE_INVISIBILITY", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9a01a9b5064f1d7efd504fc7e212aab2c8", null ],
    [ "GHK_TRANSPARENCY_TOOLBAR", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9a0ac650cc7fa5a9c3d3f513c133361f39", null ],
    [ "GHK_TRANSPARANCY", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9a092996092e1a020a316d069b263bcdd3", null ],
    [ "GHK_CHAT", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9a3386a7bc33316de51e6bdc0ea9eaf30d", null ],
    [ "GHK_CHAT_ALL", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9a4a5041690f97811ea7ff5bbe03451b42", null ],
    [ "GHK_CHAT_COMPANY", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9a6e9ddba220e30cf98bdab8a9a97014ef", null ],
    [ "GHK_CHAT_SERVER", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9a63c096645f6ecd5c1454c3e8bb56eff8", null ],
    [ "GHK_CLOSE_NEWS", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9ac60d2c78b04ac06e2540ed3f53870663", null ],
    [ "GHK_CLOSE_ERROR", "d4/d2f/main__gui_8cpp.html#aae05225933a42f81e7c4a9fb286596f9a2e7f5d6ef8e062f3ccfe0f01ee17c9e6", null ],
    [ "CcPlaySound_EXPLOSION", "d4/d2f/main__gui_8cpp.html#ad62b968c60dbf9808d102e2f67a6c40e", null ],
    [ "DoZoomInOutWindow", "d4/d2f/main__gui_8cpp.html#adaa371fce2b46799616f97226d298105", null ],
    [ "FixTitleGameZoom", "d4/d2f/main__gui_8cpp.html#a06d73d45c4871fa5dd174257b8013b2c", null ],
    [ "GameSizeChanged", "d4/d2f/main__gui_8cpp.html#a4560d58565a10931cc872203e4507e0c", null ],
    [ "HandlePlacePushButton", "d4/d2f/main__gui_8cpp.html#adda47a64a5c71bef4d65e68a10fff5e9", null ],
    [ "IsQuitKey", "d4/d2f/main__gui_8cpp.html#a741c7924ee2ff2ded36abb79e10a7e36", null ],
    [ "SetupColoursAndInitialWindow", "d4/d2f/main__gui_8cpp.html#a55d3768f8fd70e0d8774f72cd07cb3c8", null ],
    [ "ShowSelectGameWindow", "d4/d2f/main__gui_8cpp.html#a047378c986949dd9660b677fecd96847", null ],
    [ "ShowVitalWindows", "d4/d2f/main__gui_8cpp.html#a09240eb994f64bbd4dc0deef77da9263", null ],
    [ "ZoomInOrOutToCursorWindow", "d4/d2f/main__gui_8cpp.html#ad33aa4a7c820c1165c9265e2ef32041b", null ],
    [ "_ghk_abandon_keys", "d4/d2f/main__gui_8cpp.html#a5f25b4d5715ea614462edcf99b61e82c", null ],
    [ "_ghk_chat_all_keys", "d4/d2f/main__gui_8cpp.html#abb3ac94f4fc3059a9916921341ca9eb6", null ],
    [ "_ghk_chat_company_keys", "d4/d2f/main__gui_8cpp.html#a6cbbdfe69dcfcf312f62d921afcc51f9", null ],
    [ "_ghk_chat_keys", "d4/d2f/main__gui_8cpp.html#a3056e523e6df2326b5473a22f74e82ab", null ],
    [ "_ghk_chat_server_keys", "d4/d2f/main__gui_8cpp.html#a751aac66ab5762a454fc2de7ec11fa92", null ],
    [ "_ghk_quit_keys", "d4/d2f/main__gui_8cpp.html#a8be278d7bcfea2842e3ed66c2a43dff1", null ],
    [ "_main_window_desc", "d4/d2f/main__gui_8cpp.html#a4a40f091cecc9fb86c5ea9c73c2093ea", null ],
    [ "_nested_main_window_widgets", "d4/d2f/main__gui_8cpp.html#a887d24014962a322a719b9232c6d2e9a", null ],
    [ "global_hotkeys", "d4/d2f/main__gui_8cpp.html#a95061e381e0685497be87418a562ef98", null ]
];
